
#region Using Directives

using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;

#endregion Using Directives

namespace Helper.Windows
{
	/// <summary>
	/// Summary description for DialogBox.
	/// </summary>
	public class DialogBox : System.Windows.Forms.Form
	{
		#region Members

		#region Form

		private System.Windows.Forms.GroupBox groupBox1;
		private System.Windows.Forms.PictureBox pictureBox;
		private System.Windows.Forms.Label messageString;
		private System.Windows.Forms.Button buttonOK;
		private System.Windows.Forms.Button buttonCancel;
		private System.Windows.Forms.Button buttonYes;
		private System.Windows.Forms.ImageList imageList1;
		private System.Windows.Forms.Button buttonNo;
		private System.ComponentModel.IContainer components;

		#endregion Form

		#region Data

		private DialogBoxButtons selectedButtons;
		private DialogBoxIcons selectedIcon;
		private System.Windows.Forms.Button buttonOKOnly;
		private string message;
		private string header;
		private int winWidth;
		private int winHeight;

		#endregion Data

		#endregion Members

		#region Construction

		/// <summary>
		/// Constructs a DialogBox.
		/// </summary>
		/// <param name="messageText"></param>
		public DialogBox(string messageText)
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			this.selectedIcon = DialogBoxIcons.Info;
			this.selectedButtons = DialogBoxButtons.OK;
			this.message = messageText;
			this.header = string.Empty;
			
			InitializeDialog();
		}

		/// <summary>
		/// Constructs a DialogBox.
		/// </summary>
		/// <param name="messageText"></param>
		/// <param name="button"></param>
		public DialogBox(string messageText, DialogBoxButtons button)
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			this.selectedIcon = DialogBoxIcons.Info;
			this.selectedButtons = button;
			this.message = messageText;
			this.header = string.Empty;
			
			InitializeDialog();
		}

		/// <summary>
		/// Constructs a DialogBox.
		/// </summary>
		/// <param name="messageText"></param>
		/// <param name="button"></param>
		/// <param name="icon"></param>
		public DialogBox(string messageText, DialogBoxButtons button, DialogBoxIcons icon)
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			this.selectedIcon = icon;
			this.selectedButtons = button;
			this.message = messageText;
			switch(icon)
			{
				case DialogBoxIcons.Info:
					this.header = "Information";
					break;
				case DialogBoxIcons.Question:
					this.header = "Frga";
					break;
				case DialogBoxIcons.Warning:
					this.header = "Varning";
					break;
				case DialogBoxIcons.Critical:
					this.header = "Fel";
					break;
			}
			
			InitializeDialog();
		}

		/// <summary>
		/// Constructs a DialogBox.
		/// </summary>
		/// <param name="messageText"></param>
		/// <param name="headerText"></param>
		/// <param name="button"></param>
		/// <param name="icon"></param>
		public DialogBox(string messageText, string headerText, DialogBoxButtons button, DialogBoxIcons icon)
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			this.selectedIcon = icon;
			this.selectedButtons = button;
			this.message = messageText;
			this.header = headerText;
			
			InitializeDialog();
		}

		/// <summary>
		/// Constructs a DialogBox.
		/// </summary>
		/// <param name="messageText"></param>
		/// <param name="headerText"></param>
		/// <param name="button"></param>
		/// <param name="icon"></param>
		/// <param name="width"></param>
		/// <param name="height"></param>
		public DialogBox(string messageText, string headerText, DialogBoxButtons button, DialogBoxIcons icon, int width, int height)
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			this.selectedIcon = icon;
			this.selectedButtons = button;
			this.message = messageText;
			this.header = headerText;
			
			//Calculate the width and height difference compared to the original size.
			//If the values get negative the window ends up smaller than original
			int widthDifference = width - this.Width;
			int heightDifference = height - this.Height;
			
			//Modify the sizes of all involved controls in the dialog box.
			this.Height += heightDifference;
			this.Width += widthDifference;

			this.messageString.Height += heightDifference;
			this.messageString.Width += widthDifference;

			this.groupBox1.Height += heightDifference;
			this.groupBox1.Width += widthDifference;

			//Move control positions to fit the new dialog layout.
			this.buttonYes.Location = new Point(this.buttonYes.Location.X + widthDifference, this.buttonYes.Location.Y + heightDifference);
			this.buttonNo.Location = new Point(this.buttonNo.Location.X + widthDifference, this.buttonNo.Location.Y + heightDifference);
			this.buttonOKOnly.Location = new Point(this.buttonOKOnly.Location.X + widthDifference, this.buttonOKOnly.Location.Y + heightDifference);
			this.buttonOK.Location = new Point(this.buttonOK.Location.X + widthDifference, this.buttonOK.Location.Y + heightDifference);
			this.buttonCancel.Location = new Point(this.buttonCancel.Location.X + widthDifference, this.buttonCancel.Location.Y + heightDifference);
			
			InitializeDialog();
		}

		#endregion Construction

		#region Initialize

		/// <summary>
		/// 
		/// </summary>
		private void InitializeDialog()
		{
			switch(selectedIcon)
			{
				case DialogBoxIcons.Info:
					this.Icon = System.Drawing.SystemIcons.Information;
					break;
				case DialogBoxIcons.Question:
					this.Icon = System.Drawing.SystemIcons.Question;
					break;
				case DialogBoxIcons.Warning:
					this.Icon = System.Drawing.SystemIcons.Warning;
					break;
				case DialogBoxIcons.Critical:
					this.Icon = System.Drawing.SystemIcons.Error;
					break;
			}
			
			switch(selectedButtons)
			{
				case DialogBoxButtons.OK:
				{
					this.buttonCancel.Visible = false;
					this.buttonOK.Visible = false;
					this.buttonYes.Visible = false;
					this.buttonNo.Visible = false;
					this.buttonOKOnly.Visible = true;
					break;
				}
				case DialogBoxButtons.OKCancel:
				{
					this.buttonCancel.Visible = true;
					this.buttonOK.Visible = true;
					this.buttonYes.Visible = false;
					this.buttonNo.Visible = false;
					this.buttonOKOnly.Visible = false;
					break;
				}
				case DialogBoxButtons.YesNo:
				{
					this.buttonCancel.Visible = false;
					this.buttonOK.Visible = false;
					this.buttonYes.Visible = true;
					this.buttonNo.Visible = true;
					this.buttonOKOnly.Visible = false;
					break;
				}
				case DialogBoxButtons.YesNoCancel:
				{
					this.buttonCancel.Visible = true;
					this.buttonOK.Visible = false;
					this.buttonYes.Visible = true;
					this.buttonNo.Visible = true;
					this.buttonOKOnly.Visible = false;
					break;
				}
				default:
				{
					break;
				}
			}

			this.pictureBox.Image = this.imageList1.Images[Convert.ToInt32(this.selectedIcon)];
			this.messageString.Text = this.message;
			this.Text = this.header;
		}

		#endregion Initialize

		#region Overrides

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#endregion Overrides

		#region Properties

		/// <summary>
		/// 
		/// </summary>
		public DialogBoxButtons DialogBoxButton
		{
			get{return this.selectedButtons;}
			set{this.selectedButtons = value;}
		}
		
		/// <summary>
		/// 
		/// </summary>
		public DialogBoxIcons DialogBoxIcon
		{
			get{return this.selectedIcon;}
			set{this.selectedIcon = value;}
		}

		/// <summary>
		/// 
		/// </summary>
		public string Message
		{
			get{return this.message;}
			set{this.message = value;}
		}

		/// <summary>
		/// 
		/// </summary>
		public string Header
		{
			get{return this.header;}
			set{this.header = value;}
		}

		/// <summary>
		/// 
		/// </summary>
		public int WindowWidth
		{
			get{return this.winWidth;}
			set{this.winWidth = value;}
		}

		/// <summary>
		/// 
		/// </summary>
		public int WindowHeight
		{
			get{return this.winHeight;}
			set{this.winHeight = value;}
		}

		#endregion Properties

		#region Event Handlers

		#region Buttons

		private void buttonNo_Click(object sender, System.EventArgs e)
		{
		
		}

		private void buttonYes_Click(object sender, System.EventArgs e)
		{
		
		}

		private void buttonCancel_Click(object sender, System.EventArgs e)
		{
		
		}

		private void buttonOK_Click(object sender, System.EventArgs e)
		{
		
		}

		private void buttonOKOnly_Click(object sender, System.EventArgs e)
		{
		
		}
		
		#endregion Buttons

		#endregion Event Handlers

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.components = new System.ComponentModel.Container();
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(DialogBox));
			this.buttonOK = new System.Windows.Forms.Button();
			this.buttonCancel = new System.Windows.Forms.Button();
			this.groupBox1 = new System.Windows.Forms.GroupBox();
			this.messageString = new System.Windows.Forms.Label();
			this.pictureBox = new System.Windows.Forms.PictureBox();
			this.buttonYes = new System.Windows.Forms.Button();
			this.imageList1 = new System.Windows.Forms.ImageList(this.components);
			this.buttonNo = new System.Windows.Forms.Button();
			this.buttonOKOnly = new System.Windows.Forms.Button();
			this.groupBox1.SuspendLayout();
			this.SuspendLayout();
			// 
			// buttonOK
			// 
			this.buttonOK.DialogResult = System.Windows.Forms.DialogResult.OK;
			this.buttonOK.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.buttonOK.Location = new System.Drawing.Point(496, 88);
			this.buttonOK.Name = "buttonOK";
			this.buttonOK.TabIndex = 0;
			this.buttonOK.Text = "OK";
			this.buttonOK.Click += new System.EventHandler(this.buttonOK_Click);
			// 
			// buttonCancel
			// 
			this.buttonCancel.DialogResult = System.Windows.Forms.DialogResult.Cancel;
			this.buttonCancel.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.buttonCancel.Location = new System.Drawing.Point(584, 88);
			this.buttonCancel.Name = "buttonCancel";
			this.buttonCancel.TabIndex = 1;
			this.buttonCancel.Text = "Avbryt";
			this.buttonCancel.Click += new System.EventHandler(this.buttonCancel_Click);
			// 
			// groupBox1
			// 
			this.groupBox1.Controls.Add(this.messageString);
			this.groupBox1.Controls.Add(this.pictureBox);
			this.groupBox1.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.groupBox1.Location = new System.Drawing.Point(8, 8);
			this.groupBox1.Name = "groupBox1";
			this.groupBox1.Size = new System.Drawing.Size(648, 72);
			this.groupBox1.TabIndex = 2;
			this.groupBox1.TabStop = false;
			// 
			// messageString
			// 
			this.messageString.Location = new System.Drawing.Point(64, 16);
			this.messageString.Name = "messageString";
			this.messageString.Size = new System.Drawing.Size(576, 48);
			this.messageString.TabIndex = 4;
			// 
			// pictureBox
			// 
			this.pictureBox.Location = new System.Drawing.Point(8, 16);
			this.pictureBox.Name = "pictureBox";
			this.pictureBox.Size = new System.Drawing.Size(48, 48);
			this.pictureBox.TabIndex = 3;
			this.pictureBox.TabStop = false;
			// 
			// buttonYes
			// 
			this.buttonYes.DialogResult = System.Windows.Forms.DialogResult.Yes;
			this.buttonYes.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.buttonYes.Location = new System.Drawing.Point(408, 88);
			this.buttonYes.Name = "buttonYes";
			this.buttonYes.TabIndex = 3;
			this.buttonYes.Text = "Ja";
			this.buttonYes.Click += new System.EventHandler(this.buttonYes_Click);
			// 
			// imageList1
			// 
			this.imageList1.ColorDepth = System.Windows.Forms.ColorDepth.Depth16Bit;
			this.imageList1.ImageSize = new System.Drawing.Size(48, 48);
			this.imageList1.ImageStream = ((System.Windows.Forms.ImageListStreamer)(resources.GetObject("imageList1.ImageStream")));
			this.imageList1.TransparentColor = System.Drawing.Color.Transparent;
			// 
			// buttonNo
			// 
			this.buttonNo.DialogResult = System.Windows.Forms.DialogResult.No;
			this.buttonNo.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.buttonNo.Location = new System.Drawing.Point(496, 88);
			this.buttonNo.Name = "buttonNo";
			this.buttonNo.TabIndex = 4;
			this.buttonNo.Text = "Nej";
			this.buttonNo.Click += new System.EventHandler(this.buttonNo_Click);
			// 
			// buttonOKOnly
			// 
			this.buttonOKOnly.DialogResult = System.Windows.Forms.DialogResult.OK;
			this.buttonOKOnly.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.buttonOKOnly.Location = new System.Drawing.Point(584, 88);
			this.buttonOKOnly.Name = "buttonOKOnly";
			this.buttonOKOnly.TabIndex = 5;
			this.buttonOKOnly.Text = "OK";
			this.buttonOKOnly.Click += new System.EventHandler(this.buttonOKOnly_Click);
			// 
			// DialogBox
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(674, 120);
			this.Controls.Add(this.buttonOKOnly);
			this.Controls.Add(this.buttonNo);
			this.Controls.Add(this.buttonYes);
			this.Controls.Add(this.groupBox1);
			this.Controls.Add(this.buttonCancel);
			this.Controls.Add(this.buttonOK);
			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
			this.MaximizeBox = false;
			this.MinimizeBox = false;
			this.Name = "DialogBox";
			this.ShowInTaskbar = false;
			this.StartPosition = System.Windows.Forms.FormStartPosition.CenterParent;
			this.TopMost = true;
			this.groupBox1.ResumeLayout(false);
			this.ResumeLayout(false);

		}
		#endregion
	}
}
